#
# spec file for package proton-vpn
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%if 0%{?suse_version} >= 1600
%global pythons python3
%else
%global pythons python311
%endif
Name:           proton-vpn
Version:        4.3.2
Release:        1.1
Summary:        Official Proton VPN client
License:        GPL-3.0-or-later
Group:          Productivity/Networking/Security
URL:            https://github.com/ProtonVPN/proton-vpn-gtk-app
Source:         https://github.com/ProtonVPN/proton-vpn-gtk-app/archive/refs/tags/v%{version}.tar.gz
Patch1:         setup-data-files.patch
BuildRequires:  %{pythons}-dbus-python
BuildRequires:  %{pythons}-gobject
BuildRequires:  %{pythons}-packaging
BuildRequires:  %{pythons}-proton-vpn-api-core >= 0.21.0
BuildRequires:  %{pythons}-proton-vpn-connection >= 0.14.2
BuildRequires:  %{pythons}-proton-vpn-killswitch-network-manager
BuildRequires:  %{pythons}-proton-vpn-logger
BuildRequires:  %{pythons}-proton-vpn-network-manager-openvpn
BuildRequires:  %{pythons}-pycairo
BuildRequires:  %{pythons}-pytest
BuildRequires:  %{pythons}-pytest-cov
BuildRequires:  %{pythons}-setuptools
BuildRequires:  fdupes
BuildRequires:  gobject-introspection
BuildRequires:  gtk3-devel
BuildRequires:  python-rpm-macros
BuildRequires:  update-desktop-files
Requires:       %{pythons}-dbus-python
Requires:       %{pythons}-gobject
Requires:       %{pythons}-packaging
Requires:       %{pythons}-proton-vpn-api-core >= 0.24.0
Requires:       %{pythons}-proton-vpn-connection >= 0.14.2
Requires:       %{pythons}-proton-vpn-killswitch-network-manager
Requires:       %{pythons}-proton-vpn-logger
Requires:       %{pythons}-proton-vpn-network-manager-openvpn
Requires:       %{pythons}-pycairo
Requires:       gtk3
Conflicts:      protonvpn-gui
Provides:       protonvpn-app = %{version}
BuildArch:      noarch

%description
The Proton VPN client is easy to use and packed with advanced features
carefully designed to improve your online security.

%prep
%setup -q -n proton-vpn-gtk-app-%{version}
%autopatch -p1

%build
%python3_build

%install
%python3_install
%fdupes %{buildroot}%{python3_sitelib}/

mkdir -p %{buildroot}/%{_datadir}/icons/hicolor/scalable/apps/
mkdir -p %{buildroot}/%{_datadir}/applications
cp rpmbuild/SOURCES/proton-vpn-logo.svg %{buildroot}/%{_datadir}/icons/hicolor/scalable/apps/proton-vpn.svg

%suse_update_desktop_file -c proton-vpn "Proton VPN" "Proton VPN Client" protonvpn-app proton-vpn "GTK;Network;Utility"

%check
# ignore UI tests as they segfault with no desktop env
%pytest tests/unit --ignore=tests/unit/widgets/

%files
%doc README.md
%license LICENSE COPYING.md
%{_datadir}/applications/proton-vpn.desktop
%{_datadir}/icons/hicolor/*/apps/proton-vpn.*
%{python3_sitelib}/proton/
%{python3_sitelib}/proton_vpn_gtk_app-%{version}*.egg-info
%{_bindir}/protonvpn-app

%changelog
* Wed May 22 2024 Alexandre Vicenzi <alexandre.vicenzi@suse.com>
- Add setup-data-files.patch to fix erroneous files being installed
- Update package
  * 4.3.2
  - We no longer call UsageReporting.init to initialize UsageReporting.
  - Only initialize sentry on first enable.
  - Forward SSL_CERT_FILE environment variable to sentry.
  * 4.3.1
  - Ensure behavioral consistency when opening settings window across different distributions
  - Update label alignment on disable kill switch widget at login
  - Missed the minimum python3-proton-vpn-api-core version in build_packages.py
  - Switch to using sessions module that is now bundled with vpn-api-core
  - Update wireguard certificate request when settings are changed
  - Add connection features to the wireguard certificate request
  - Periodically refresh certificate
  * 4.3.0
  - Provide the possibility to disable Kill Switch if user is logged out and Kill Switch is set to permanent
  - Ensure that protocol list in settings UI is properly capitalized and alphabetically ordered
  - Anonymous crash reports are now sent by default, this can be disabled in the settings
  - Change how we build debian and rpm packages. We now depend on a single versions.yml file to build everything
  - Increase minimum number of characters required for bug report description
* Thu Mar 21 2024 Alexandre Vicenzi <alexandre.vicenzi@suse.com>
- Update to 4.2.0
  * Add overlay when connecting to server
  * Upon logging out or quitting, inform the user about the kill switch status
  * Apply kill switch settings immediately
  * Add permanent option to kill switch setting
  * Fix minor bug in country row initialization
* Fri Feb  9 2024 Alexandre Vicenzi <alexandre.vicenzi@suse.com>
- Initial revision
